summaryrefslogtreecommitdiff
path: root/plugins/HistoryStats/src/statistic.h
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2016-12-22 18:58:01 +0300
committerGeorge Hazan <ghazan@miranda.im>2016-12-22 18:58:01 +0300
commit38517d7f3b0a1dd04ee111fa721d9f4ec4c3a104 (patch)
tree8d84c985e25f99383f133ae925bce0413b90b16d /plugins/HistoryStats/src/statistic.h
parentdd9cf5468a032542f422f6301654d87b557c7cc4 (diff)
ughm
Diffstat (limited to 'plugins/HistoryStats/src/statistic.h')
-rw-r--r--plugins/HistoryStats/src/statistic.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/HistoryStats/src/statistic.h b/plugins/HistoryStats/src/statistic.h
index c08661a373..b3dbe6fc2a 100644
--- a/plugins/HistoryStats/src/statistic.h
+++ b/plugins/HistoryStats/src/statistic.h
@@ -10,7 +10,6 @@
#include <list>
#include "settings.h"
-#include "protocol.h"
#include "message.h"
class Contact; // forward declaration instead of #include "contact.h"
@@ -83,8 +82,9 @@ private:
Contact* m_pTotals;
Contact* m_pOmitted;
- // did we really omit something
- bool m_bActuallyOmitted;
+ bool
+ m_bActuallyOmitted, // did we really omit something
+ m_bResult; // result of calculations
// start time for statistics
DWORD m_TimeStarted;
@@ -159,7 +159,7 @@ private:
// private constructor & main statistic creation routine
explicit Statistic(const Settings& settings, InvocationSource invokedFrom, HINSTANCE hInst);
bool createStatistics();
- bool createStatisticsSteps();
+ void createStatisticsSteps();
static void __cdecl threadProc(void *lpParameter);
static void __cdecl threadProcSteps(void *lpParameter);